class PayException(Exception):
    pass


class DateException(Exception):
    pass


class AuthException(Exception):
    pass


class OtherException(Exception):
    pass


class NotFoundException(Exception):
    pass


class UploadException(Exception):
    pass


class BlockIpException(Exception):
    pass


class ValidatorException(Exception):
    pass


class DuplicateException(Exception):
    pass


class PermissionException(Exception):
    pass